# -*- coding: utf-8 -*-
# Generated by Django 1.11.16 on 2019-02-14 14:51
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion
import djangocms_pai_custom_elements.models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('cms', '0020_old_tree_cleanup'),
    ]

    operations = [
        migrations.CreateModel(
            name='GenericCustomElement',
            fields=[
                ('cmsplugin_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, related_name='djangocms_pai_custom_elements_genericcustomelement', serialize=False, to='cms.CMSPlugin')),
                ('label', models.CharField(blank=True, help_text='Overrides the display name in the structure mode.', max_length=255, verbose_name='Label')),
                ('classes', models.CharField(blank=True, help_text='Additional comma separated list of classes to be added to the element e.g. "row, column-12, clearfix".', max_length=255, verbose_name='Additional classes')),
                ('id_name', models.CharField(blank=True, max_length=255, verbose_name='ID name')),
                ('attributes', djangocms_pai_custom_elements.models.Attribute(blank=True, default=dict, verbose_name='Attributes')),
                ('js', models.TextField(blank=True, null=True)),
                ('css', models.TextField(blank=True, null=True)),
                ('tag_type', models.CharField(max_length=255, verbose_name='Tag type')),
                ('template', models.CharField(default='generic-custom-element.html', max_length=255, verbose_name='Template')),
                ('js_asset', models.FileField(blank=True, null=True, upload_to='custom_elements/js_assets', verbose_name='JS asset')),
                ('css_asset', models.FileField(blank=True, null=True, upload_to='custom_elements/css_assets', verbose_name='CSS asset')),
                ('async_load', models.BooleanField(default=False)),
            ],
            options={
                'verbose_name_plural': 'Generic CustomElements',
                'verbose_name': 'Generic CustomElement',
            },
            bases=('cms.cmsplugin',),
        ),
    ]
